/*
 * $Id: host.h,v 1.3 1998/08/10 23:09:45 gregm Exp $
 * GXSNMP -- An snmp management application
 * Copyright (C) 1998 Gregory McLean
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
 *
 * Host include file.
 */
#ifndef __HOST_H__
#define __HOST_H__
#include "snmp_host.h"

struct hostent *lookuphost 	   (char *hostname);
hosts          *find_host          (const char *hostname);
hosts          *hl_add_host        (hosts *entry);
void           hl_del_host         (hosts *entry);
hosts          *get_current_host   (void);
void           add_interface       (hosts *entry, inf_list *interface);
void           remove_interface    (hosts *entry, inf_list *interface);
void           show_interface_list (hosts *entry);
inf_list       *find_interface     (struct in_addr *if_addr);

#endif

/* EOF */
